@@ -206,14 +206,14 @@ class CreateRoomRequest(AbstractModel):
 2 高清
 3 全高清
         :type Resolution: int
-        :param MaxMicNumber: 最大连麦人数（不包括老师）。取值范围[0, 17)
+        :param MaxMicNumber: 最大连麦人数（不包括老师）。取值范围[0, 16]
         :type MaxMicNumber: int
         :param SubType: 房间子类型，可以有以下取值：
 videodoc 文档+视频
 video 纯视频
 coteaching 双师
         :type SubType: str
-        :param TeacherId: 老师ID。
+        :param TeacherId: 老师ID。通过[注册用户]接口获取的UserId。
         :type TeacherId: str
         :param AutoMic: 进入房间时是否自动连麦。可以有以下取值：
 0 不自动连麦（默认值）
@@ -227,7 +227,7 @@ coteaching 双师
 0 不禁止录制（默认值）
 1 禁止录制
         :type DisableRecord: int
-        :param Assistants: 助教Id列表。
+        :param Assistants: 助教Id列表。通过[注册用户]接口获取的UserId。
         :type Assistants: list of str
         :param RecordLayout: 录制布局。
         :type RecordLayout: int
@@ -401,7 +401,7 @@ class DescribeRoomResponse(AbstractModel):
 2 高清
 3 全高清
         :type Resolution: int
-        :param MaxMicNumber: 最大连麦人数（不包括老师）。取值范围[0, 17)
+        :param MaxMicNumber: 最大连麦人数（不包括老师）。取值范围[0, 16]
         :type MaxMicNumber: int
         :param AutoMic: 进入房间时是否自动连麦。可以有以下取值：
 0 不自动连麦（默认值）
@@ -764,7 +764,7 @@ class ModifyAppRequest(AbstractModel):
         r"""
         :param SdkAppId: 低代码互动课堂的SdkAppId。
         :type SdkAppId: int
-        :param Callback: 回调地址。
+        :param Callback: 回调地址。端口目前仅支持80、443
         :type Callback: str
         """
         self.SdkAppId = None
